All pastes #1340493 Raw Edit

Miscellany

public diff v1 · immutable
#1340493 ·published 2009-02-17 21:54 UTC
rendered paste body
Index: tests/test_sched.c===================================================================--- tests/test_sched.c	(revision 176699)+++ tests/test_sched.c	(working copy)@@ -23,6 +23,7 @@  * \author Russell Bryant <russell@digium.com>  */ +#include <inttypes.h> #include "asterisk.h"  ASTERISK_FILE_VERSION(__FILE__, "$Revision$")@@ -86,7 +87,7 @@ 		} 	} -	ast_cli(a->fd, "Test complete - %ld us\n", ast_tvdiff_us(ast_tvnow(), start));+	ast_cli(a->fd, "Test complete - %" PRIi64 " us\n", ast_tvdiff_us(ast_tvnow(), start));  	ast_cli(a->fd, "Testing ast_sched_del() performance - timing how long it takes " 			"to delete %u entries with random time intervals from 0 to 60 seconds\n", num);@@ -100,7 +101,7 @@ 		} 	} -	ast_cli(a->fd, "Test complete - %ld us\n", ast_tvdiff_us(ast_tvnow(), start));+	ast_cli(a->fd, "Test complete - %" PRIi64 " us\n", ast_tvdiff_us(ast_tvnow(), start));  return_cleanup: 	sched_context_destroy(con);